# HG changeset patch
# Node ID 276440de063b
# Parent  45fef383cf60
diff --git a/pidgin/meson.build b/pidgin/meson.build
--- a/pidgin/meson.build
+++ b/pidgin/meson.build
@@ -23,6 +23,7 @@
 	'pidginaccountfilterconnected.c',
 	'pidginaccountfilterprotocol.c',
 	'pidginaccountmanager.c',
+	'pidginaccountsdisabledmenu.c',
 	'pidginaccountsenabledmenu.c',
 	'pidginaccountsmenu.c',
 	'pidginaccountstore.c',
@@ -39,7 +40,6 @@
 	'pidgindebug.c',
 	'pidgindialog.c',
 	'pidginiconname.c',
-	'pidgininactiveaccountsmenu.c',
 	'pidgininfopane.c',
 	'pidgininvitedialog.c',
 	'pidginmessage.c',
@@ -99,6 +99,7 @@
 	'pidginaccountfilterconnected.h',
 	'pidginaccountfilterprotocol.h',
 	'pidginaccountmanager.h',
+	'pidginaccountsdisabledmenu.h',
 	'pidginaccountsenabledmenu.h',
 	'pidginaccountsmenu.h',
 	'pidginaccountstore.h',
@@ -115,7 +116,6 @@
 	'pidgindialog.h',
 	'pidgindebug.h',
 	'pidginiconname.h',
-	'pidgininactiveaccountsmenu.h',
 	'pidgininfopane.h',
 	'pidgininvitedialog.h',
 	'pidginmessage.h',
diff --git a/pidgin/pidgininactiveaccountsmenu.c b/pidgin/pidginaccountsdisabledmenu.c
rename from pidgin/pidgininactiveaccountsmenu.c
rename to pidgin/pidginaccountsdisabledmenu.c
--- a/pidgin/pidgininactiveaccountsmenu.c
+++ b/pidgin/pidginaccountsdisabledmenu.c
@@ -22,22 +22,22 @@
 
 #include <glib/gi18n.h>
 
-#include "pidgininactiveaccountsmenu.h"
+#include "pidginaccountsdisabledmenu.h"
 
-struct _PidginInactiveAccountsMenu {
+struct _PidginAccountsDisabledMenu {
 	GMenuModel parent;
 
 	GList *accounts;
 };
 
-G_DEFINE_TYPE(PidginInactiveAccountsMenu, pidgin_inactive_accounts_menu,
+G_DEFINE_TYPE(PidginAccountsDisabledMenu, pidgin_accounts_disabled_menu,
               G_TYPE_MENU_MODEL)
 
 /******************************************************************************
  * Callbacks
  *****************************************************************************/
 static void
-pidgin_inactive_accounts_menu_refresh(PidginInactiveAccountsMenu *menu) {
+pidgin_accounts_disabled_menu_refresh(PidginAccountsDisabledMenu *menu) {
 	PurpleAccountManager *manager = NULL;
 	gint removed = 0, added = 0;
 
@@ -62,27 +62,27 @@
 }
 
 static void
-pidgin_inactive_accounts_menu_changed_cb(G_GNUC_UNUSED PurpleAccount *account,
+pidgin_accounts_disabled_menu_changed_cb(G_GNUC_UNUSED PurpleAccount *account,
                                          gpointer data)
 {
-	PidginInactiveAccountsMenu *menu = data;
+	PidginAccountsDisabledMenu *menu = data;
 
-	pidgin_inactive_accounts_menu_refresh(menu);
+	pidgin_accounts_disabled_menu_refresh(menu);
 }
 
 /******************************************************************************
  * GMenuModel Implementation
  *****************************************************************************/
 static gboolean
-pidgin_inactive_accounts_menu_is_mutable(GMenuModel *model) {
+pidgin_accounts_disabled_menu_is_mutable(GMenuModel *model) {
 	return TRUE;
 }
 
 static gboolean
-pidgin_inactive_accounts_menu_get_n_items(GMenuModel *model) {
-	PidginInactiveAccountsMenu *menu = NULL;
+pidgin_accounts_disabled_menu_get_n_items(GMenuModel *model) {
+	PidginAccountsDisabledMenu *menu = NULL;
 
-	menu = PIDGIN_INACTIVE_ACCOUNTS_MENU(model);
+	menu = PIDGIN_ACCOUNTS_DISABLED_MENU(model);
 
 	if(menu->accounts == NULL) {
 		return 1;
@@ -92,17 +92,17 @@
 }
 
 static void
-pidgin_inactive_accounts_menu_get_item_attributes(GMenuModel *model,
+pidgin_accounts_disabled_menu_get_item_attributes(GMenuModel *model,
                                                   gint index,
                                                   GHashTable **attributes)
 {
-	PidginInactiveAccountsMenu *menu = NULL;
+	PidginAccountsDisabledMenu *menu = NULL;
 	PurpleAccount *account = NULL;
 	PurpleProtocol *protocol = NULL;
 	GVariant *value = NULL;
 	const gchar *account_name = NULL, *protocol_name = NULL;
 
-	menu = PIDGIN_INACTIVE_ACCOUNTS_MENU(model);
+	menu = PIDGIN_ACCOUNTS_DISABLED_MENU(model);
 
 	/* Create our hash table of attributes to return. */
 	*attributes = g_hash_table_new_full(g_str_hash, g_str_equal, NULL,
@@ -156,7 +156,7 @@
 }
 
 static void
-pidgin_inactive_accounts_menu_get_item_links(GMenuModel *model, gint index,
+pidgin_accounts_disabled_menu_get_item_links(GMenuModel *model, gint index,
                                              GHashTable **links)
 {
 	*links = g_hash_table_new_full(g_str_hash, g_str_equal, g_free,
@@ -167,51 +167,51 @@
  * GObject Implementation
  *****************************************************************************/
 static void
-pidgin_inactive_accounts_menu_dispose(GObject *obj) {
+pidgin_accounts_disabled_menu_dispose(GObject *obj) {
 	purple_signals_disconnect_by_handle(obj);
 
-	G_OBJECT_CLASS(pidgin_inactive_accounts_menu_parent_class)->dispose(obj);
+	G_OBJECT_CLASS(pidgin_accounts_disabled_menu_parent_class)->dispose(obj);
 }
 
 static void
-pidgin_inactive_accounts_menu_constructed(GObject *obj) {
-	G_OBJECT_CLASS(pidgin_inactive_accounts_menu_parent_class)->constructed(obj);
+pidgin_accounts_disabled_menu_constructed(GObject *obj) {
+	G_OBJECT_CLASS(pidgin_accounts_disabled_menu_parent_class)->constructed(obj);
 
-	pidgin_inactive_accounts_menu_refresh(PIDGIN_INACTIVE_ACCOUNTS_MENU(obj));
+	pidgin_accounts_disabled_menu_refresh(PIDGIN_ACCOUNTS_DISABLED_MENU(obj));
 }
 
 static void
-pidgin_inactive_accounts_menu_init(PidginInactiveAccountsMenu *menu) {
+pidgin_accounts_disabled_menu_init(PidginAccountsDisabledMenu *menu) {
 	gpointer handle = NULL;
 
 	/* Wire up the purple signals we care about. */
 	handle = purple_accounts_get_handle();
 	purple_signal_connect(handle, "account-enabled", menu,
-	                      G_CALLBACK(pidgin_inactive_accounts_menu_changed_cb),
+	                      G_CALLBACK(pidgin_accounts_disabled_menu_changed_cb),
 	                      menu);
 	purple_signal_connect(handle, "account-disabled", menu,
-	                      G_CALLBACK(pidgin_inactive_accounts_menu_changed_cb),
+	                      G_CALLBACK(pidgin_accounts_disabled_menu_changed_cb),
 	                      menu);
 }
 
 static void
-pidgin_inactive_accounts_menu_class_init(PidginInactiveAccountsMenuClass *klass) {
+pidgin_accounts_disabled_menu_class_init(PidginAccountsDisabledMenuClass *klass) {
 	GObjectClass *obj_class = G_OBJECT_CLASS(klass);
 	GMenuModelClass *model_class = G_MENU_MODEL_CLASS(klass);
 
-	obj_class->constructed = pidgin_inactive_accounts_menu_constructed;
-	obj_class->dispose = pidgin_inactive_accounts_menu_dispose;
+	obj_class->constructed = pidgin_accounts_disabled_menu_constructed;
+	obj_class->dispose = pidgin_accounts_disabled_menu_dispose;
 
-	model_class->is_mutable = pidgin_inactive_accounts_menu_is_mutable;
-	model_class->get_n_items = pidgin_inactive_accounts_menu_get_n_items;
-	model_class->get_item_attributes = pidgin_inactive_accounts_menu_get_item_attributes;
-	model_class->get_item_links = pidgin_inactive_accounts_menu_get_item_links;
+	model_class->is_mutable = pidgin_accounts_disabled_menu_is_mutable;
+	model_class->get_n_items = pidgin_accounts_disabled_menu_get_n_items;
+	model_class->get_item_attributes = pidgin_accounts_disabled_menu_get_item_attributes;
+	model_class->get_item_links = pidgin_accounts_disabled_menu_get_item_links;
 }
 
 /******************************************************************************
  * Public API
  *****************************************************************************/
 GMenuModel *
-pidgin_inactive_accounts_menu_new(void) {
-	return g_object_new(PIDGIN_TYPE_INACTIVE_ACCOUNTS_MENU, NULL);
+pidgin_accounts_disabled_menu_new(void) {
+	return g_object_new(PIDGIN_TYPE_ACCOUNTS_DISABLED_MENU, NULL);
 }
diff --git a/pidgin/resources/gtk/menus.ui b/pidgin/resources/gtk/menus.ui
--- a/pidgin/resources/gtk/menus.ui
+++ b/pidgin/resources/gtk/menus.ui
@@ -184,7 +184,7 @@
         <submenu>
           <attribute name="label" translatable="yes">_Enable Account</attribute>
 
-          <section id="inactive-accounts"/>
+          <section id="disabled-accounts"/>
         </submenu>
       </section>
       <section id="enabled-accounts"/>
diff --git a/po/POTFILES.in b/po/POTFILES.in
--- a/po/POTFILES.in
+++ b/po/POTFILES.in
@@ -339,6 +339,7 @@
 pidgin/pidginaccountfilterconnected.c
 pidgin/pidginaccountfilterprotocol.c
 pidgin/pidginaccountmanager.c
+pidgin/pidginaccountsdisabledmenu.c
 pidgin/pidginaccountsenabledmenu.c
 pidgin/pidginaccountsmenu.c
 pidgin/pidginaccountstore.c
@@ -356,7 +357,6 @@
 pidgin/pidgindebug.c
 pidgin/pidgindialog.c
 pidgin/pidginiconname.c
-pidgin/pidgininactiveaccountsmenu.c
 pidgin/pidgininfopane.c
 pidgin/pidgininvitedialog.c
 pidgin/pidginmessage.c

diff --git a/pidgin/pidginapplication.c b/pidgin/pidginapplication.c
--- a/pidgin/pidginapplication.c
+++ b/pidgin/pidginapplication.c
@@ -44,11 +44,11 @@
 #include "gtkxfer.h"
 #include "pidginabout.h"
 #include "pidginaccountmanager.h"
+#include "pidginaccountsdisabledmenu.h"
 #include "pidginaccountsenabledmenu.h"
 #include "pidginconversationwindow.h"
 #include "pidgincore.h"
 #include "pidgindebug.h"
-#include "pidgininactiveaccountsmenu.h"
 #include "pidginmooddialog.h"
 #include "pidginpluginsdialog.h"
 #include "pidginpluginsmenu.h"
@@ -124,10 +124,10 @@
 	GMenu *source = NULL, *target = NULL;
 	GMenuModel *model = NULL;
 
-	/* Link the InactiveAccountsMenu into its proper location. */
-	model = pidgin_inactive_accounts_menu_new();
+	/* Link the AccountsDisabledMenu into its proper location. */
+	model = pidgin_accounts_disabled_menu_new();
 	target = gtk_application_get_menu_by_id(GTK_APPLICATION(application),
-	                                        "inactive-accounts");
+	                                        "disabled-accounts");
 	g_menu_append_section(target, NULL, model);
 
 	/* Link the AccountsEnabledMenu into its proper location. */
diff --git a/pidgin/pidgininactiveaccountsmenu.h b/pidgin/pidginaccountsdisabledmenu.h
rename from pidgin/pidgininactiveaccountsmenu.h
rename to pidgin/pidginaccountsdisabledmenu.h
--- a/pidgin/pidgininactiveaccountsmenu.h
+++ b/pidgin/pidginaccountsdisabledmenu.h
@@ -24,8 +24,8 @@
 # error "only <pidgin.h> may be included directly"
 #endif
 
-#ifndef PIDGIN_INACTIVE_ACCOUNTS_MENU_H
-#define PIDGIN_INACTIVE_ACCOUNTS_MENU_H
+#ifndef PIDGIN_ACCOUNTS_DISABLED_MENU_H
+#define PIDGIN_ACCOUNTS_DISABLED_MENU_H
 
 #include <glib.h>
 #include <gio/gio.h>
@@ -34,22 +34,22 @@
 
 G_BEGIN_DECLS
 
-#define PIDGIN_TYPE_INACTIVE_ACCOUNTS_MENU (pidgin_inactive_accounts_menu_get_type())
-G_DECLARE_FINAL_TYPE(PidginInactiveAccountsMenu, pidgin_inactive_accounts_menu,
-                     PIDGIN, INACTIVE_ACCOUNTS_MENU, GMenuModel)
+#define PIDGIN_TYPE_ACCOUNTS_DISABLED_MENU (pidgin_accounts_disabled_menu_get_type())
+G_DECLARE_FINAL_TYPE(PidginAccountsDisabledMenu, pidgin_accounts_disabled_menu,
+                     PIDGIN, ACCOUNTS_DISABLED_MENU, GMenuModel)
 
 /**
- * pidgin_inactive_accounts_menu_new:
+ * pidgin_accounts_disabled_menu_new:
  *
  * Creates a menu that will automatically update itself to include accounts
  * that are inactive in libpurple.
  *
  * Returns: (transfer full): The new menu instance.
  *
  * Since: 3.0.0
  */
-GMenuModel *pidgin_inactive_accounts_menu_new(void);
+GMenuModel *pidgin_accounts_disabled_menu_new(void);
 
 G_END_DECLS
 
-#endif /* PIDGIN_INACTIVE_ACCOUNTS_MENU_H */
\ No newline at end of file
+#endif /* PIDGIN_ACCOUNTS_DISABLED_MENU_H */
\ No newline at end of file
@@ -34,22 +34,22 @@
  *
  * Creates a menu that will automatically update itself to include accounts
- * that are inactive in libpurple.
+ * that are disabled in libpurple.
  *
  * Returns: (transfer full): The new menu instance.